import { ParsedModel, Token } from './types';
export declare type SliceToken = string | Token | SliceMark;
export declare type SliceRange = [number, number];
export interface SliceMark {
    type: 'slice';
    /** Token location in original text */
    location: number;
    /** Either open or closing mark */
    close: boolean;
}
export interface FragmentOptions {
    /** List of allowed tags in extracted fragment, including parents (if enabled) */
    tags?: string[];
}
export declare class SliceResult {
    /**
     * Extracted document content with `SliceOp` indicators for inserting open
     * and close wrapper tag, if required
     */
    tokens: SliceToken[];
    /** Range of original document tokens included inside `token` fragment */
    range: SliceRange;
    constructor(tokens: SliceToken[], range: SliceRange);
    /**
     * Returns string representation of current fragment.
     * @param opTag Tag name for wrap markers
     */
    toString(opTag?: string): string;
    /**
     * Returns list of tag tokens
     */
    toTokens(opTag: string): Token[];
    /**
     * Converts current slice result to diff token
     */
    toDiffToken(name: string, text: string, location: number): Token;
}
/**
 * Returns document fragment for given _text content_ range that can be used as
 * a _replacement_ for the same range of given document.
 * Inserts `SliceOp` operation markers in appropriate positions to maintain valid
 * XML state.
 * @param start Token location hint in parsed document where to start fragment lookup
 */
export declare function slice(doc: ParsedModel, from: number, to: number, start?: number): SliceResult;
export declare function fragment(doc: ParsedModel, from: number, to: number, options?: FragmentOptions): SliceResult;
/**
 * A slice mark factory
 */
export declare function sliceMark(location: number, close?: boolean): SliceMark;
export declare function isSliceMark(value: any): value is SliceMark;
export declare function isSliceMarkOpen(value: any): value is SliceMark;
export declare function isSliceMarkClose(value: any): value is SliceMark;
